diff --git a/configure.ac b/configure.ac
index b7598bb..caff704 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1200,7 +1198,7 @@ dnl
 VLC_ADD_PLUGINS([dummy logger memcpy])
 VLC_ADD_PLUGINS([mpgv mpga m4v m4a h264 vc1 demux_cdg cdg ps pva avi asf mp4 rawdv rawvid nsv real aiff mjpeg demuxdump flacsys tta])
 VLC_ADD_PLUGINS([cvdsub svcdsub spudec subsdec subsusf t140 dvbsub cc mpeg_audio lpcm a52 dts cinepak flac])
-VLC_ADD_PLUGINS([deinterlace invert adjust transform wave ripple psychedelic gradient motionblur rv32 rotate noise grain extract sharpen seamcarving croppadd])
+VLC_ADD_PLUGINS([deinterlace invert adjust transform wave ripple psychedelic gradient motionblur rv32 rotate noise grain extract sharpen seamcarving croppadd ascii])
 VLC_ADD_PLUGINS([converter_fixed mono])
 VLC_ADD_PLUGINS([trivial_resampler ugly_resampler])
 VLC_ADD_PLUGINS([trivial_channel_mixer trivial_mixer])
diff --git a/modules/video_filter/Modules.am b/modules/video_filter/Modules.am
index fb3c14c..3880343 100644
--- a/modules/video_filter/Modules.am
+++ b/modules/video_filter/Modules.am
@@ -36,4 +36,5 @@ SOURCES_gaussianblur = gaussianblur.c
 SOURCES_grain = grain.c
 SOURCES_seamcarving = seamcarving.c
 SOURCES_croppadd = croppadd.c
+SOURCES_ascii = ascii.c
 noinst_HEADERS = filter_common.h filter_picture.h
diff --git a/modules/video_filter/ascii.c b/modules/video_filter/ascii.c
new file mode 100644
index 0000000..7421827
--- /dev/null
+++ b/modules/video_filter/ascii.c
@@ -0,0 +1,176 @@
+/*****************************************************************************
+ * ascii.c : Ascii video filter for vlc
+ *****************************************************************************
+ * Copyright (C) 2000-2008 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Sven Rech <svenrech@gmx.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+/*****************************************************************************
+ * Preamble
+ *****************************************************************************/
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <vlc/vlc.h>
+#include <vlc_vout.h>
+
+#include "vlc_filter.h"
+
+/*****************************************************************************
+ * Local prototypes
+ *****************************************************************************/
+static int  Create      ( vlc_object_t * );
+static void Destroy     ( vlc_object_t * );
+
+static picture_t *Filter( filter_t *, picture_t * );
+
+/*****************************************************************************
+ * Module descriptor
+ *****************************************************************************/
+vlc_module_begin();
+    set_description( _("Ascii video filter") );
+    set_shortname( _("Show video as Ascii" ));
+    set_category( CAT_VIDEO );
+    set_subcategory( SUBCAT_VIDEO_VFILTER );
+    set_capability( "video filter2", 0 );
+    add_shortcut( "ascii" );
+    set_callbacks( Create, Destroy );
+vlc_module_end();
+
+/*****************************************************************************
+ * vout_sys_t: Ascii video output method descriptor
+ *****************************************************************************/
+struct filter_sys_t
+{
+    int frame;
+};
+
+const char ascii_data[] = 
+{
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0,
+	0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 0,
+	0, 1, 1, 0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0,
+	0, 1, 1, 0, 1, 1, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0,
+	0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0,
+	0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0,
+	0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0,
+	0, 0, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0,
+	0, 0, 0, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0
+};
+const int ascii_width = 18;
+const int ascii_height = 10;
+
+/*****************************************************************************
+ * Create: allocates Ascii video thread output method
+ *****************************************************************************/
+static int Create( vlc_object_t *p_this )
+{
+    filter_t *p_filter = (filter_t *)p_this;
+
+    /* Allocate structure */
+    p_filter->p_sys = malloc( sizeof( filter_sys_t ) );
+    if( p_filter->p_sys == NULL )
+    {
+        msg_Err( p_filter, "out of memory" );
+        return VLC_ENOMEM;
+    }
+
+    p_filter->pf_video_filter = Filter;
+
+    return VLC_SUCCESS;
+}
+
+/*****************************************************************************
+ * Destroy: destroy Ascii video thread output method
+ *****************************************************************************/
+static void Destroy( vlc_object_t *p_this )
+{
+    filter_t *p_filter = (filter_t *)p_this;
+
+    free( p_filter->p_sys );
+}
+
+static picture_t *Filter( filter_t *p_filter, picture_t *p_pic )
+{
+    picture_t *p_outpic;
+    int i_index;
+    int i_planes;
+
+    if( !p_pic ) return NULL;
+
+    p_outpic = p_filter->pf_vout_buffer_new( p_filter );
+    if( !p_outpic )
+    {
+        msg_Warn( p_filter, "can't get output picture" );
+        if( p_pic->pf_release )
+            p_pic->pf_release( p_pic );
+        return NULL;
+    }
+
+    i_index = 0; //Only Y plane
+    {
+        uint8_t *p_in, *p_in_end, *p_line_end, *p_out;
+
+        p_in = p_pic->p[i_index].p_pixels;
+        p_in_end = p_in + p_pic->p[i_index].i_visible_lines
+                           * p_pic->p[i_index].i_pitch;
+
+        p_out = p_outpic->p[i_index].p_pixels;
+
+        for( int line = 0; p_in < p_in_end ; line++ )
+        {
+            p_line_end = p_in + p_pic->p[i_index].i_visible_pitch;
+
+            int c = 0;
+            int delta = p_filter->p_sys->frame * (((line/ascii_height)%2 == 1)?-1:1);
+            while( p_in < p_line_end )
+            {
+		int ach = (ascii_width+(c+delta)) % ascii_width;
+                int v = ascii_data[ach + (line%ascii_height)*ascii_width];
+
+                *p_out++ = (v == 0) ? 0 : *p_in;
+                p_in++;
+                c++;
+            }
+
+            p_in += p_pic->p[i_index].i_pitch
+                     - p_pic->p[i_index].i_visible_pitch;
+            p_out += p_outpic->p[i_index].i_pitch
+                     - p_outpic->p[i_index].i_visible_pitch;
+        }
+    }
+
+    p_outpic->date = p_pic->date;
+    p_outpic->b_force = p_pic->b_force;
+    p_outpic->i_nb_fields = p_pic->i_nb_fields;
+    p_outpic->b_progressive = p_pic->b_progressive;
+    p_outpic->b_top_field_first = p_pic->b_top_field_first;
+
+    if( p_pic->pf_release )
+        p_pic->pf_release( p_pic );
+
+    p_filter->p_sys->frame++;
+    if (p_filter->p_sys->frame >= ascii_width)
+        p_filter->p_sys->frame = 0;
+
+    return p_outpic;
+}
